Index: FL/Enumerations.H
===================================================================
--- FL/Enumerations.H	(revision 10844)
+++ FL/Enumerations.H	(working copy)
@@ -427,7 +427,18 @@
       The Fl::event_dy() method can be used to find magnification amount,
       Fl::event_x() and Fl::event_y() are set as well.
      */
-  FL_ZOOM_GESTURE	= 26
+  FL_ZOOM_GESTURE	= 26,
+
+  /** The widget under the cursor has a chance to display a tooltip. 
+   *  When a widget receives this event, it can modify its tooltip. The
+   *  modified tooltip will be drawn. If the widget removes its tooltip,
+   *  the parent with a tooltip will be drawn.
+   *
+   *  See STR 2041: http://www.fltk.org/str.php?L2041
+   *
+   *  \sa Fl_Widget::tooltip(const char *t)
+   */
+  FL_TOOLTIP	= 27
 };
 
 /** \name When Conditions */
Index: FL/names.h
===================================================================
--- FL/names.h	(revision 10844)
+++ FL/names.h	(working copy)
@@ -69,8 +69,8 @@
   "FL_SCREEN_CONFIGURATION_CHANGED",
   "FL_FULLSCREEN",
   "FL_ZOOM_GESTURE",
-  "FL_EVENT_27",  // not yet defined, just in case they /will/ be defined ...
-  "FL_EVENT_28",
+  "FL_TOOLTIP",  
+  "FL_EVENT_28", // not yet defined, just in case they /will/ be defined ...
   "FL_EVENT_29",
   "FL_EVENT_30"
 };
Index: src/Fl_Group.cxx
===================================================================
--- src/Fl_Group.cxx	(revision 10844)
+++ src/Fl_Group.cxx	(working copy)
@@ -283,6 +283,10 @@
       if (o->visible()) o->handle(event);
     }
     return 1;
+ 
+  case FL_TOOLTIP:
+    if (tooltip()) return 1;
+    return 0;
 
   default:
     // For all other events, try to give to each child, starting at focus:
Index: src/Fl_Tooltip.cxx
===================================================================
--- src/Fl_Tooltip.cxx	(revision 10844)
+++ src/Fl_Tooltip.cxx	(working copy)
@@ -199,6 +199,11 @@
   for (;;) {
     if (!tw) {exit_(0); return;}
     if (tw == widget_) return;
+	
+    // Send the FL_TOOLTIP event to tw. The return value technically does not matter.
+	// The action to take will depend on the state of its tooltip.
+	tw->handle(FL_TOOLTIP);
+
     if (tw->tooltip()) break;
     tw = tw->parent();
   }
